@@ -66,7 +66,7 @@ class Population:
                             if np.random.uniform() < mutate_r8:
                                 bird.matrices[matrix][row][col] += np.random.normal(0, 1/np.sqrt(len(bird.matrices[matrix][0])) * radius_ratio, 1)[0]
                                 if np.random.uniform() < reinit:
-                                    bird.matrices[matrix][row][col] = np.random.normal(0, 1/np.sqrt(len(bird.matrices[matrix][0])))[0]
+                                    bird.matrices[matrix][row][col] = np.random.normal(0, 1/np.sqrt(len(bird.matrices[matrix][0])), 1)[0]
         random.shuffle(self.birds)
         for i in range(immune):
             del self.birds[i]
